@@ -29,8 +29,7 @@ LIBREMIDI_INLINE stdx::error midi_out_emscripten::open_port(int portNumber, std:
 
   if (portNumber >= midi.output_count())
   {
-    libremidi_handle_error(
-        this->configuration, "no MIDI output sources found.");
+    libremidi_handle_error(this->configuration, "no MIDI output sources found.");
     return std::errc::invalid_argument;
   }
 
@@ -38,16 +37,19 @@ LIBREMIDI_INLINE stdx::error midi_out_emscripten::open_port(int portNumber, std:
   return stdx::error{};
 }
 
-LIBREMIDI_INLINE stdx::error midi_out_emscripten::open_port(const output_port& p, std::string_view nm)
+LIBREMIDI_INLINE stdx::error
+midi_out_emscripten::open_port(const output_port& p, std::string_view nm)
 {
   return open_port(p.port, nm);
 }
 
-LIBREMIDI_INLINE stdx::error midi_out_emscripten::close_port() { 
+LIBREMIDI_INLINE stdx::error midi_out_emscripten::close_port()
+{
   return stdx::error{};
 }
 
-LIBREMIDI_INLINE stdx::error midi_out_emscripten::send_message(const unsigned char* message, size_t size)
+LIBREMIDI_INLINE stdx::error
+midi_out_emscripten::send_message(const unsigned char* message, size_t size)
 {
   if (m_portNumber < 0)
     libremidi_handle_error(
