@@ -14,9 +14,12 @@ PoseDetector::PoseDetector() noexcept
 PoseDetector::~PoseDetector() = default;
 
 void PoseDetector::operator()()
+try
 {
   if (!available)
     return;
+  if (current_model_invalid)
+    return;
 
   auto& in_tex = inputs.image.texture;
 
@@ -71,4 +74,8 @@ void PoseDetector::operator()()
   outputs.image.texture.changed = true;
   std::swap(storage, t.storage);
 }
+catch (...)
+{
+  current_model_invalid = true;
+}
 }
