@@ -17,7 +17,7 @@ class SCORE_LIB_BASE_EXPORT QGraphicsHSVChooser final
     , public QGraphicsItem
 {
   W_OBJECT(QGraphicsHSVChooser)
-  Q_INTERFACES(QGraphicsItem)
+  SCORE_GRAPHICS_ITEM_TYPE(50)
 private:
   QRectF m_rect{0., 0., 140., 100.};
 
