@@ -11,7 +11,7 @@ PROCESS_METADATA(
     "video",                          // Internal name
     "Video",                          // Pretty name
     Process::ProcessCategory::Visual, // Category
-    "Visuals",                        // Category
+    "Visuals/Textures",               // Category
     "Display a video",                // Description
     "ossia team",                     // Author
     (QStringList{"gfx", "video"}),    // Tags
