@@ -24,6 +24,24 @@ CentralIntervalDisplay::CentralIntervalDisplay(ScenarioDocumentPresenter& p)
 
 CentralIntervalDisplay::~CentralIntervalDisplay()
 {
+  auto& view = parent.view();
+  auto& gv = view.view();
+  if(auto itv_p = presenter.intervalPresenter())
+  {
+    QObject::disconnect(
+        itv_p, &FullViewIntervalPresenter::intervalSelected, &parent,
+        &ScenarioDocumentPresenter::setDisplayedInterval);
+  }
+  QObject::disconnect(
+      &gv, &ProcessGraphicsView::dropRequested, &parent,
+      &ScenarioDocumentPresenter::on_dropInEmptyFullView);
+
+  QObject::disconnect(
+      &presenter, &DisplayedElementsPresenter::requestFocusedPresenterChange,
+      &parent.focusManager(),
+      static_cast<void (Process::ProcessFocusManager::*)(
+          QPointer<Process::LayerPresenter>)>(&Process::ProcessFocusManager::focus));
+
   presenter.remove();
 }
 
@@ -48,7 +66,7 @@ void CentralIntervalDisplay::init()
   SCORE_ASSERT(itv_p);
   QObject::connect(
       itv_p, &FullViewIntervalPresenter::intervalSelected, &parent,
-      &ScenarioDocumentPresenter::setDisplayedInterval);
+      &ScenarioDocumentPresenter::setDisplayedInterval, Qt::UniqueConnection);
 
   parent.on_viewReady();
   parent.updateMinimap();
@@ -59,7 +77,14 @@ void CentralIntervalDisplay::init()
       &presenter, &DisplayedElementsPresenter::requestFocusedPresenterChange,
       &parent.focusManager(),
       static_cast<void (Process::ProcessFocusManager::*)(
-          QPointer<Process::LayerPresenter>)>(&Process::ProcessFocusManager::focus));
+          QPointer<Process::LayerPresenter>)>(&Process::ProcessFocusManager::focus),
+      Qt::UniqueConnection);
+
+  // In case we drop in the emptiness in the interval view, we want to
+  // create a node there and an appropriately-sized slot
+  QObject::connect(
+      &gv, &ProcessGraphicsView::dropRequested, &parent,
+      &ScenarioDocumentPresenter::on_dropInEmptyFullView, Qt::UniqueConnection);
 }
 
 Process::ProcessModel* closestParentProcessBeforeInterval(const QObject* obj)
@@ -102,7 +127,7 @@ void CentralIntervalDisplay::on_addProcessFromLibrary(const Library::ProcessData
     if(sel.size() == 1)
     {
       const Process::Cable& cbl = *sel.front();
-      createProcessInCable(parent, dat, cbl);
+      createProcessInCable(parent.context(), parent.model(), dat, {}, {}, cbl);
       return;
     }
   }
@@ -117,7 +142,7 @@ void CentralIntervalDisplay::on_addProcessFromLibrary(const Library::ProcessData
       if(!parentProcess.outlets().empty())
       {
         createProcessAfterPort(
-            parent, dat, parentProcess, *parentProcess.outlets().front());
+            parent, dat, {}, {}, parentProcess, *parentProcess.outlets().front());
       }
       else
       {
@@ -139,9 +164,9 @@ void CentralIntervalDisplay::on_addProcessFromLibrary(const Library::ProcessData
       if(parentProcess)
       {
         if(auto inl = qobject_cast<const Process::Inlet*>(&p))
-          createProcessBeforePort(parent, dat, *parentProcess, *inl);
+          createProcessBeforePort(parent, dat, {}, {}, *parentProcess, *inl);
         else if(auto inl = qobject_cast<const Process::Outlet*>(&p))
-          createProcessAfterPort(parent, dat, *parentProcess, *inl);
+          createProcessAfterPort(parent, dat, {}, {}, *parentProcess, *inl);
       }
       else if(createInParentInterval())
         return;
@@ -178,7 +203,7 @@ void CentralIntervalDisplay::on_addPresetFromLibrary(const Process::Preset& dat)
     if(sel.size() == 1)
     {
       const Process::Cable& cbl = *sel.front();
-      loadPresetInCable(parent, dat, cbl);
+      loadPresetInCable(parent.context(), parent.model(), dat, cbl);
       return;
     }
   }
